@@ -25,16 +25,16 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
+import pyatspi
 import re
 
-import pyatspi
 import braille
 import debug
 import eventsynthesizer
 import orca_state
-import rolenames
 import settings
 
+from braille_generator import BrailleGenerator
 from orca_i18n import _         # for gettext support
 from orca_i18n import C_        # to provide qualified translatable strings
 from orca_i18n import ngettext
@@ -440,11 +440,11 @@ class ValueZone(Zone):
             except:
                 percentValue = 0
 
+            rolename = self.accessible.getLocalizedRoleName()
             if orientation:
-                speechValue = orientation + " " + \
-                              rolenames.getSpeechForRoleName(self.accessible)
+                speechValue = orientation + " " + rolename
             else:
-                speechValue = rolenames.getSpeechForRoleName(self.accessible)
+                speechValue = rolename
                 
             # Translators: this is the percentage value of a slider, 
             # progress bar or other component that displays a value as 
@@ -455,15 +455,13 @@ class ValueZone(Zone):
                                      percentValue) % percentValue
             speechValue = speechValue + " " + percentString
 
+            rolename = BrailleGenerator.getLocalizedRoleName(self.accessible)
             if orientation:
                 brailleValue = "%s %s %d%%" % (orientation,
-                    rolenames.getBrailleForRoleName(self.accessible),      
+                    rolename,
                     percentValue)
             else:
-                brailleValue = "%s %d%%" % \
-                    (rolenames.getBrailleForRoleName(self.accessible),
-                    percentValue)
-
+                brailleValue = "%s %d%%" % (rolename, percentValue)
             if attr == "string":
                 return speechValue
             elif attr == "length":
@@ -579,7 +577,11 @@ class Line:
                 region.brailleOffset = brailleOffset
                 self.brailleRegions.append(region)
 
-                brailleOffset += len(region.string.decode("UTF-8"))
+                try:
+                    regionString = region.string.decode("UTF-8")
+                except UnicodeEncodeError:
+                    regionString = region.string
+                brailleOffset += len(regionString)
 
             if not settings.disableBrailleEOL:
                 if len(self.brailleRegions):
